v2.0
----

Changes
~~~~~~~
- Better-structured format for channel scans. [Ash Wilson]
- Adding CodeClimate config. [Ash Wilson]

  Removing Python2.6 because this ain't the antique roadshow.

  Closes #3
- Add "avg_absolute_error" to scan_channel() output. [Ash Wilson]


v1.1.1 (2017-01-06)
-------------------
- Update travis. [ashmastaflash]


